@@ -2,7 +2,7 @@
 *******************************************************************************
 *
 * File:         brl.c
-* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/brl.c,v 2.1 2003/01/08 15:50:53 matthew Exp $
+* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/brl.c,v 2.7 2005/01/23 11:19:58 matthew Exp $
 * Description:  Bible Retrieval Library
 * Author:       Chip Chapin, Hewlett Packard Company
 * Created:      Jan 14 1989, Chip Chapin
@@ -40,6 +40,24 @@
 *******************************************************************************
 *
 * $Log: brl.c,v $
+* Revision 2.7  2005/01/23 11:19:58  matthew
+* explicit casts
+*
+* Revision 2.6  2005/01/22 17:47:40  matthew
+* remove improper function declarations
+*
+* Revision 2.5  2005/01/22 16:40:34  matthew
+* cast return value of strlen to signed int
+*
+* Revision 2.4  2005/01/21 19:38:25  matthew
+* Code clean-up - initialise vref, remove unused variable.
+*
+* Revision 2.3  2005/01/21 19:07:31  matthew
+* disambiguate an else
+*
+* Revision 2.2  2005/01/21 19:05:51  matthew
+* Prototype all functions
+*
 * Revision 2.1  2003/01/08 15:50:53  matthew
 * applied debian patch
 *
@@ -151,14 +169,14 @@
 
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
+#include <string.h>
 #include "tsl.h"
 #include "brl.h"
 
 #define FALSE	(0)
 
-static char rcs_ident[]="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/brl.c,v 2.1 2003/01/08 15:50:53 matthew Exp $";
-
 char *booknamestr[] = { "Genesis",
 			   "Exodus",
 			   "Leviticus",
@@ -305,8 +323,6 @@ ref_t brl_cur_vnum;		/* Current context. */
 char brl_textname[]="KJV";
 
 
-ref_t verse_id( );
-ref_t verse_num( );
 
 
 /*----------------------------------------------------------------------
@@ -320,11 +336,11 @@ ref_t verse_num( );
 \*----------------------------------------------------------------------*/
 
 #define getnum(s,n)	n=0; get_nonblank(s); \
-    while (isdigit(*s)) n = 10 * n + (*s++ - '0');
+    while (isdigit((int)*s)) n = 10 * n + (*s++ - '0');
 
 
 
-int get_book( s, book )
+int get_book(char **s,int book)
 /*----------------------------------------------------------------------
 |   NAME:
 |       get_book
@@ -342,9 +358,6 @@ int get_book( s, book )
 |       890904 cc Revised to allow non-fatal errors.
 |
 \*----------------------------------------------------------------------*/
-
-char **s;
-int book;
 {
     int c;
     char *s1;
@@ -352,7 +365,7 @@ int book;
     book = -2;		/* assume no book is given */
     get_nonblank(*s);
     s1 = *s;
-    if (*s1 && (isalpha(*s1) || isalpha(*(s1+1)))) {
+    if (*s1 && (isalpha((int)*s1) || isalpha((int)*(s1+1)))) {
 	switch (c = *s1++) {
 	  case '1':	/* 1Sa, 1Ki, 1Ch, 1Co, 1Th, 1Ti, 1Pe, 1Jn */
 	  case '2':	/* 2Sa, 2Ki, 2Ch, 2Co, 2Th, 2Ti, 2Pe, 2Jn */
@@ -392,12 +405,13 @@ int book;
 		return -1;
 	    }
 	    if (c != '1') book++;
-	    if (c == '3') 
-		if (book == (int)JOHN2) book++;
-		else {
-		    tsl_error( FALSE, BADBOOK, *s );
-		    return -1;
-		}
+	    if (c == '3'){ 
+	      if (book == (int)JOHN2) book++;
+	      else {
+		tsl_error( FALSE, BADBOOK, *s );
+		return -1;
+	      }
+	    }
 	    break;
 	  case 'a': /* amos, acts */
 	    c = *s1++;
@@ -562,7 +576,7 @@ int book;
 		    /* phili, philp, phil, phi, ph, php, pp, etc. */
 		    /* This gives preference to Philippians over Philemon */
 		    book = (int)PHILIP;
-			 if (!isalpha(c)) *s1--; /* point back to the chapter number */
+			 if (!isalpha(c)) s1--; /* point back to the chapter number */
 		} else if (c == 'e' || c == 'm') book = (int)PHILEM;
 		else {
 		    tsl_error( FALSE, BADBOOK, *s );
@@ -605,7 +619,7 @@ int book;
 	} /* switch on first letter of book name */
 	
 	/* Skip any remaining letters in book name */
-	while (isalpha(*s1)) s1++;
+	while (isalpha((int)*s1)) s1++;
 	get_nonblank(s1);
     }
     *s = s1;
@@ -614,7 +628,7 @@ int book;
 
 
 
-int verse_continuation( s, book, chapter, verse, absverse )
+int verse_continuation(char **s,int book,int chapter,int verse,ref_t absverse)
 /*----------------------------------------------------------------------
 |   NAME:
 |       verse_continuation
@@ -642,10 +656,6 @@ int verse_continuation( s, book, chapter, verse, absverse )
 |       890908 cc Error return.
 |
 \*----------------------------------------------------------------------*/
-
-char **s;
-int book, chapter, verse;
-ref_t absverse;
 {
     int	n;
     char *s1;
@@ -678,7 +688,7 @@ ref_t absverse;
 
 
 
-ref_t verse_id( s, bookp, chapterp, versep )
+ref_t verse_id(char **s,int *bookp,int *chapterp,int *versep )
 /*----------------------------------------------------------------------
 |   NAME:
 |       verse_id
@@ -709,9 +719,6 @@ ref_t verse_id( s, bookp, chapterp, versep )
 |       890908 cc Fix to blank line handling.  Revised error return.
 |
 \*----------------------------------------------------------------------*/
-
-char **s;
-int *bookp, *chapterp, *versep;
 {
     short book, chapter, verse;
     int   num;
@@ -786,7 +793,7 @@ int *bookp, *chapterp, *versep;
 
 
 
-ref_t brl_extract_num( absverse, bp, cp, vp )
+ref_t brl_extract_num(ref_t absverse,int *bp,int *cp,int *vp)
 /*----------------------------------------------------------------------
 |   NAME:
 |       brl_extract_num
@@ -804,9 +811,6 @@ ref_t brl_extract_num( absverse, bp, cp, vp )
 |       890904 cc Created (in a hurry)
 |
 \*----------------------------------------------------------------------*/
-
-ref_t absverse;
-int *bp, *cp, *vp;
 {
     int bk, chp;
 
@@ -835,7 +839,7 @@ int *bp, *cp, *vp;
 
 
 
-ref_t verse_num(b, c, v)
+ref_t verse_num(int b,int c,int v)
 /*----------------------------------------------------------------------
 |   NAME:
 |       verse_num
@@ -857,8 +861,6 @@ ref_t verse_num(b, c, v)
 |       	error checking.
 |
 \*----------------------------------------------------------------------*/
-
-int b, c, v;
 {
     int abschapter;
     ref_t absverse;
@@ -876,7 +878,7 @@ int b, c, v;
 
 
 
-ref_t brl_verse_spec( s, n )
+ref_t brl_verse_spec(char **s,int *n)
 /*----------------------------------------------------------------------
 |   NAME:
 |       brl_verse_spec
@@ -894,9 +896,6 @@ ref_t brl_verse_spec( s, n )
 |   HISTORY:
 |
 \*----------------------------------------------------------------------*/
-
-char	**s;
-int	*n;
 {
     ref_t av;
     char *s1;
@@ -910,7 +909,7 @@ int	*n;
     get_nonblank(*s);
     s1 = *s;
     while (*s1) {
-	if (isupper(*s1)) *s1 = tolower(*s1);
+	if (isupper((int)*s1)) *s1 = tolower((int)*s1);
 	if (*s1 == ',')
 	    *s1 = ' ';
 	else if (*s1 == '\n')
@@ -969,7 +968,7 @@ int  pretty, lwidth;
 #endif
 
 
-ref_t brl_printverse( vs, pretty, lwidth, outf )
+ref_t brl_printverse(char *vs,int pretty,int lwidth,FILE *outf)
 /*----------------------------------------------------------------------
 |   NAME:
 |       brl_printverse
@@ -996,15 +995,10 @@ ref_t brl_printverse( vs, pretty, lwidth, outf )
 |       991230 oe Increase VBSIZE to avoid verse truncation.
 |
 \*----------------------------------------------------------------------*/
-
-char *vs;
-int  pretty;
-int  lwidth;
-FILE *outf;
 {
-    ref_t vn, vref;
+    ref_t vn, vref=0;
     int vc, vcount;
-    int len, indent, i;
+    int len, indent;
 /* Length of the longest line is 535, so original length of 512 was not enough */
 #define VBSIZE 550
     char vb1[VBSIZE], vb2[VBSIZE];
@@ -1055,7 +1049,7 @@ FILE *outf;
 
 		if (lwidth) {
 		    /* Line width limitation. */
-		    while (strlen(srcp) > (lwidth-indent)) {
+		    while ((int)strlen(srcp) > (lwidth-indent)) {
 			/* split this line.  But where? */
 			endp=srcp+lwidth-indent;
 			while (*endp!=' ' && endp>srcp) endp--;
@@ -1104,7 +1098,7 @@ FILE *outf;
 
 
 
-char* brl_num_to_ref( vbuf, absversep )
+char* brl_num_to_ref(char *vbuf,ref_t *absversep)
 /*----------------------------------------------------------------------
 |   NAME:
 |       brl_num_to_ref
@@ -1123,9 +1117,6 @@ char* brl_num_to_ref( vbuf, absversep )
 |       921217 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *vbuf;
-ref_t *absversep;
 {
     int bk, chp, v;
     
@@ -1136,7 +1127,7 @@ ref_t *absversep;
 
 
 
-brl_init( dfname, dfpath, memlimit )
+void brl_init(char *dfname,char *dfpath,int memlimit)
 /*----------------------------------------------------------------------
 |   NAME:
 |       brl_init
@@ -1154,9 +1145,6 @@ brl_init( dfname, dfpath, memlimit )
 |       890905 cc Added filename and paths.
 |
 \*----------------------------------------------------------------------*/
-
-int memlimit;
-char *dfname, *dfpath;
 {
     if (dfname == NULL)
 	dfname = "bible.data";
@@ -1172,7 +1160,7 @@ char *dfname, *dfpath;
 } /* brl_init */
 
 
-brl_close()
+void brl_close(void)
 /*----------------------------------------------------------------------
 |   NAME:
 |       brl_close
